<?php
/**
 * Branch 7.x-6.x introduced huge API changes.
 * This file contains wrapper functions for backward compatibility to
 * methods of the 7.x-5.x branch.
 */


/**
 * Searches JIRA issues filtered by the given JQL string.
 *
 * Usage example returning issues not resolved/closed from PROJECTNAME:
 *
 * $foundissues = jira_rest_searchissue("project=PROJECTNAME&status!=RESOLVED&status!=CLOSED");
 *
 * @param string $jql_string
 *   the JQLString (filtering the searched issues)
 * @param array $options
 *   overwrites default values of specified options (see official JIRA REST API documentation for further information):
 *     maxResults int maximum number of issues returned
 *     startAt int index of the first issue to return (0-based)
 *     fields string comma-separated list of fields that should be returned
 *     expand string comma-separated list of parameters to extend
 *     validateQuery boolean whether to validate the JQL query
 * @see jira_rest_default_curl_options
 *
 * @return object
 *   the issues found, can be accessed via array->issues
 *   some examples for getting information from a single issue:
 *   $issuekey = $issue->key;
 *   $parentkey = $issue->fields->parent->key;
 *   $customfielddata = $issue->fields->customfield_10404;
 *
 * @throws JiraRestException
 *
 * @deprecated
 */
function jira_rest_searchissue($jql_string, $options = array()) {
  $options['allowMultipleCalls'] = FALSE; // this option was never allowed for this method

  $issues = jira_rest_issue_search($jql_string, $options);
  $issues_object = new stdClass;
  $issues_object->issues = $issues;

  return $issues_object;
}


/**
 * @see jira_rest_issue_search
 * @deprecated
 */
function jira_rest_searchissue_all_issues($jql_string, $options = array()) {
  return jira_rest_issue_search($jql_string, $options);
}


/**
 * @see jira_rest_issue_get
 * @deprecated
 */
function jira_rest_getfullissue($issue_key, $options = array()) {
  return jira_rest_issue_get($issue_key, $options);
}

/**
 * @see jira_rest_issue_create
 * @deprecated
 */
function jira_rest_createissue($issue_data, $options = array()) {
  return jira_rest_issue_create($issue_data, $options);
}

/**
 * @see jira_rest_issue_update
 * @deprecated
 */
function jira_rest_updateissue($issue_data, $issue_key, $options = array()) {
  return jira_rest_issue_update($issue_key, $issue_data, $options);
}

/**
 * @see jira_rest_issue_attach_files_absolutepath
 * @deprecated
 */
function jira_rest_attachmultiplefilestoissue_absolutepath($files, $issue_key, $options = array()) {
  return jira_rest_issue_attach_files_absolutepath($issue_key, $files, $options);
}

/**
 * @see jira_rest_issue_attach_file_absolutepath
 * @deprecated
 */
function jira_rest_attachfiletoissue_absolutepath($filepath, $issue_key, $options = array()) {
  return jira_rest_issue_attach_file_absolutepath($issue_key, $filepath, $options);
}

/**
 * @see jira_rest_issue_attach_file
 * @deprecated
 */
function jira_rest_attachfiletoissue($filename, $issue_key, $options = array()) {
  return jira_rest_issue_attach_file($issue_key, $filename, $options);
}

/**
 * @see jira_rest_issue_close_fixed
 * @deprecated
 */
function jira_rest_closeissuefixed($issue_key, $transition_data = array(), $options = array()) {
  return jira_rest_issue_close_fixed($issue_key, $transition_data, $options);
}

/**
 * @see jira_rest_issue_resolve_fixed
 * @deprecated
 */
function jira_rest_resolveissuefixed($issue_key, $transition_data = array(), $options = array()) {
  return jira_rest_issue_resolve_fixed($issue_key, $transition_data, $options);
}

/**
 * @see jira_rest_issue_worklog
 * @deprecated
 */
function jira_rest_get_worklog($issue_id, $options = array()) {
  return jira_rest_issue_worklog($issue_id, $options);
}

/**
 * @see jira_rest_project_get
 * @deprecated
 */
function jira_rest_get_project($options = array()) {
  return jira_rest_project_get($options);
}

/**
 * @see jira_rest_status_get
 * @deprecated
 */
function jira_rest_get_status($options = array()) {
  return jira_rest_status_get($options);
}

/**
 * @see jira_rest_create_comment
 * @deprecated
 */
function jira_rest_create_comment($comment_data, $issue_key, $options = array()) {
  return jira_rest_issue_create_comment($issue_key, $comment_data, $options);
}

/**
 * @see jira_rest_custom_field_option_get
 * @deprecated
 */
function jira_rest_get_customFieldOption($id, $options = array()) {
  return jira_rest_custom_field_option_get($id, $options);
}

/**
 * @see jira_rest_issue_update
 * @deprecated
 */
function jira_rest_updateticket($issue_data, $issue_key, $options = array()) {
  return jira_rest_issue_update($issue_key, $issue_data, $options);
}